@@ -8,19 +8,20 @@ def ensure_reusable_venv():
     subprocess.run(["poetry", "config", "--local", "virtualenvs.path", "--unset"])
 
 
-def run_install_command():
-    subprocess.run(["poetry", "install", "--only", "main", "--quiet"])
+def run_install_command(is_verbose):
+    quiet = [] if is_verbose else ["--quiet"]
+    subprocess.run(["poetry", "install", "--only", "main"] + quiet)
 
 
 def navigate_to(path: Path):
     os.chdir(str(path))
 
 
-def install_deps(destination: Path):
+def install_deps(destination: Path, is_verbose: bool):
     current_dir = Path.cwd()
 
     navigate_to(destination)
     ensure_reusable_venv()
-    run_install_command()
+    run_install_command(is_verbose)
 
     navigate_to(current_dir)
